@@ -5,7 +5,7 @@ from datetime import date, timedelta
 
 from pagador.configuracao.cadastro import CampoFormulario, FormularioBase, TipoDeCampo, CadastroBase, SelecaoBase, FormatoDeCampo, ValidadorBase, caminho_para_template
 from pagador.configuracao.cliente import Script, TipoScript
-from pagador.configuracao.models import Banco, BoletoCarteira
+from pagador.configuracao.models import Banco, BoletoCarteira, PagamentoNaoConfigurado
 from pagador_boleto.extensao.requisicao import EnviarPedido, TipoBoleto
 
 
@@ -71,6 +71,8 @@ class MeioPagamentoCadastro(CadastroBase):
             return {"content": {"erro": u"Por favor atualize as suas informações, salve e tente novamente."}, "status": 400}
         except ValueError:
             return {"content": {"erro": u"Não foi possível gerar o boleto. Por favor atualize as suas informações, salve e tente novamente."}, "status": 400}
+        except PagamentoNaoConfigurado, ex:
+            return {"content": {"erro": u"Salve as informações do boleto para gerar um boleto de teste."}, "status": 400}
 
 
 class ValidarJson(ValidadorBase):
@@ -85,13 +87,13 @@ class ValidarJson(ValidadorBase):
         def so_numeros(s):
             return u''.join([x for x in s if x.isdigit()])
 
-        for i in ['empresa_cnpj', 'banco_agencia', 'banco_conta', 'banco_convenio']:
+        for i in ['cnpj_cpf', 'banco_agencia', 'banco_conta', 'banco_convenio']:
             if data.get(i):
                 valor = so_numeros(data[i])
-                if i != 'empresa_cnpj' and not valor:
+                if i != 'cnpj_cpf' and not valor:
                     self.erros[i] = u"Informação inválida. Deve conter apenas digitos."
-                if i == 'empresa_cnpj' and len(valor) < 14:
-                    self.erros['empresa_cnpj'] = u"CNPJ da empresa inválido."
+                if i == 'cnpj_cpf' and (len(valor) != 14 and len(valor) != 11):
+                    self.erros['cnpj_cpf'] = u"CPF/CNPJ inválido. Deve ter 14 digitos para CNPJ ou 11 para CPF"
 
         if data.get('desconto_valor', None):
             try:
